@@ -44,7 +44,7 @@ def pytest_addoption(parser):
                     action="store_false",
                     default=True,
                     dest="validate_requests",
-                    help="Validate outgoing requests" )
+                    help="Validate outgoing requests")
 
     group.addoption('--not_validate_swagger_spec',
                     action="store_false",
@@ -71,22 +71,21 @@ def pytest_configure(config):
             'use_models': config.getoption('use_models')
         }
         for spec in config.getoption('swagger_url'):
-             create(SwaggerClient.from_url(
-                    spec,
-                    request_headers=json.loads(headers),
-                    config=bravado_config
+            create(SwaggerClient.from_url(
+                spec,
+                request_headers=json.loads(headers),
+                config=bravado_config
                 )
              )
 
 
 def get_request_example(resource):
-    schema = resource.operation.params['body'].param_spec['schema']
-    example = [schema.get('example')]
-    if not example:
-        definition_name = Path(schema['$ref']).name
-        deref = resource.operation.swagger_spec.deref_flattened_spec['definitions'][definition_name]
-        example = nested_lookup('example', deref)
-    return example[0]
+    for param in resource.operation.params.values():
+        if 'schema' not in param.param_spec:
+            return nested_lookup('example', param.param_spec)
+        definition_name = Path(param.param_spec['schema']['$ref']).name
+        deref = resource.operation.swagger_spec.deref_flattened_spec['definitions'].get(definition_name)
+        return nested_lookup('example', deref)
 
 
 def update_body(body, param):
@@ -101,21 +100,19 @@ def create(client):
     for resource in attrgetter(*dir(client))(client):
         for path in dir(resource):
             operation = getattr(resource, path)
-            globals()[path] = generate_fixtures(
-                operation,
-                body=get_request_example(operation)
-            )
+            globals()[path] = generate_fixtures(operation, get_request_example(operation))
 
 
-def generate_fixtures(resource, body):
+def generate_fixtures(resource, example):
     @pytest.fixture()
     def _fixture(request):
-        param = getattr(request, 'param', [])
-        if 'no_example' in param:
-            return resource
-        if body:
-            return resource(body=update_body(body, param))
-        if param:
-            return resource(body=param)
+        if body := getattr(request, 'param', []):
+            if example:
+                body = update_body(example, body)
+            response = resource(body=body[0]).response()
+            response.request_body = response.metadata.incoming_response._delegate.request.body
+            return response
+        if example:
+            return resource(body=example[0])
         return resource
     return _fixture
